You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/03/11 06:40:54 UTC

svn commit: r752380 [2/9] - in /incubator/jsecurity/trunk: ./ core/src/org/apache/ki/ core/src/org/apache/ki/aop/ core/src/org/apache/ki/authc/ core/src/org/apache/ki/authc/credential/ core/src/org/apache/ki/authc/pam/ core/src/org/apache/ki/authz/ cor...

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationHandler.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/aop/AnnotationHandler.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationHandler.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationHandler.java&p1=incubator/jsecurity/trunk/core/src/org/ki/aop/AnnotationHandler.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/aop/AnnotationMethodInterceptor.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationMethodInterceptor.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.aop;
+package org.apache.ki.aop;
 
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Method;
 
+
 /**
  * MethodInterceptor that inspects a specific annotation on the method invocation before continuing
  * its execution.
@@ -73,7 +74,7 @@
      * The default implementation merely gets the underlying {@link Method Method} from the supplied
      * <code>MethodInvocation</code> argument, and returns:
      * <p/>
-     * <code>mi.{@link Method#getAnnotation(Class) getAnnotation}({@link AnnotationHandler#getAnnotationClass() handler.getAnnotationClass()});</code>
+     * <code>mi.{@link Method#getAnnotation(Class) getAnnotation}({@link org.apache.ki.aop.AnnotationHandler#getAnnotationClass() handler.getAnnotationClass()});</code>
      *
      * @param mi the MethodInvocation wrapping the Method from which the Annotation will be acquired.
      * @return the Annotation that this interceptor will process for the specified method invocation.
@@ -86,8 +87,7 @@
         }
         Method m = mi.getMethod();
         if (m == null) {
-            String msg = MethodInvocation.class.getName() + " parameter incorrectly " +
-                    "constructed.  getMethod() returned null";
+            String msg = MethodInvocation.class.getName() + " parameter incorrectly constructed.  getMethod() returned null";
             throw new IllegalArgumentException(msg);
 
         }

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptor.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInterceptor.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptor.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptor.java&p1=incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInterceptor.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInterceptor.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptor.java Wed Mar 11 05:40:38 2009
@@ -35,7 +35,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.aop;
+package org.apache.ki.aop;
 
 /**
  * A <tt>MethodInterceptor</tt> intercepts a <tt>MethodInvocation</tt> to perform before or after logic (aka 'advice').

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptorSupport.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInterceptorSupport.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptorSupport.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptorSupport.java&p1=incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInterceptorSupport.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInvocation.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInvocation.java Wed Mar 11 05:40:38 2009
@@ -35,7 +35,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.aop;
+package org.apache.ki.aop;
 
 import java.lang.reflect.Method;
 

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AbstractAuthenticator.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/AbstractAuthenticator.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AbstractAuthenticator.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AbstractAuthenticator.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/AbstractAuthenticator.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/AccountException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AccountException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Exception thrown due to a problem with the account

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AccountException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationException.java Wed Mar 11 05:40:38 2009
@@ -16,9 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
+
+import org.apache.ki.JSecurityException;
 
-import org.ki.JSecurityException;
 
 /**
  * General exception thrown due to an error during the Authentication process.

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationInfo.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationInfo.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationInfo.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationInfo.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationInfo.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationListenerRegistrar.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListenerRegistrar.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 import java.util.Collection;
 

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationToken.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationToken.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationToken.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationToken.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationToken.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationToken.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationToken.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 import java.io.Serializable;
 

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationToken.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationToken.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Authenticator.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/Authenticator.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Authenticator.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Authenticator.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/Authenticator.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/ConcurrentAccessException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ConcurrentAccessException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Thrown when an authentication attempt has been received for an account that has already been

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ConcurrentAccessException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ConcurrentAccessException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/CredentialsException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/CredentialsException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/CredentialsException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/CredentialsException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/CredentialsException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/CredentialsException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/CredentialsException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Exception thrown due to a problem with the credential(s) submitted for an

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/CredentialsException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/CredentialsException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/DisabledAccountException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/DisabledAccountException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/DisabledAccountException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/DisabledAccountException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/DisabledAccountException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/DisabledAccountException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/DisabledAccountException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Thrown when attempting to authenticate and the corresponding account has been disabled for

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/DisabledAccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/DisabledAccountException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExcessiveAttemptsException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/ExcessiveAttemptsException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExcessiveAttemptsException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExcessiveAttemptsException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/ExcessiveAttemptsException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/ExcessiveAttemptsException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExcessiveAttemptsException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Thrown when a system is configured to only allow a certain number of authentication attempts

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExcessiveAttemptsException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExcessiveAttemptsException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExpiredCredentialsException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/ExpiredCredentialsException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExpiredCredentialsException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExpiredCredentialsException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/ExpiredCredentialsException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/ExpiredCredentialsException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExpiredCredentialsException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Thrown during the authentication process when the system determines the submitted credential(s)

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExpiredCredentialsException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ExpiredCredentialsException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/IncorrectCredentialsException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/IncorrectCredentialsException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/IncorrectCredentialsException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/IncorrectCredentialsException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/IncorrectCredentialsException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/IncorrectCredentialsException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/IncorrectCredentialsException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Thrown when attempting to authenticate with credential(s) that do not match the actual

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/IncorrectCredentialsException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/IncorrectCredentialsException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/InetAuthenticationToken.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/InetAuthenticationToken.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/InetAuthenticationToken.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/InetAuthenticationToken.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/InetAuthenticationToken.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/InetAuthenticationToken.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/InetAuthenticationToken.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 import java.net.InetAddress;
 

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LockedAccountException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/LockedAccountException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LockedAccountException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LockedAccountException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/LockedAccountException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/LockedAccountException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LockedAccountException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * A special kind of <tt>DisabledAccountException</tt>, this exception is thrown when attempting

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LockedAccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LockedAccountException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LogoutAware.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/LogoutAware.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LogoutAware.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LogoutAware.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/LogoutAware.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/LogoutAware.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/LogoutAware.java Wed Mar 11 05:40:38 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
-import org.ki.subject.PrincipalCollection;
+import org.apache.ki.subject.PrincipalCollection;
 
 /**
  * An SPI interface allowing cleanup logic to be executed during logout of a previously authenticated Subject/user.

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/MergableAuthenticationInfo.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/MergableAuthenticationInfo.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/MergableAuthenticationInfo.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/MergableAuthenticationInfo.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/MergableAuthenticationInfo.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/MergableAuthenticationInfo.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/MergableAuthenticationInfo.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * <p>An extension of the {@link AuthenticationInfo} interface to be implemented by

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/RememberMeAuthenticationToken.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/RememberMeAuthenticationToken.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/RememberMeAuthenticationToken.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/RememberMeAuthenticationToken.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/RememberMeAuthenticationToken.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/RememberMeAuthenticationToken.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/RememberMeAuthenticationToken.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * An <tt>AuthenticationToken</tt> that indicates if the user wishes their identity to be remembered across sessions.

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAccount.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/SimpleAccount.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAccount.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAccount.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/SimpleAccount.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/UnknownAccountException.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UnknownAccountException.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * Thrown when attempting to authenticate with a principal that doesn't exist in the system (e.g.

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UnknownAccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UnknownAccountException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UsernamePasswordToken.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/UsernamePasswordToken.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UsernamePasswordToken.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UsernamePasswordToken.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/UsernamePasswordToken.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/AllowAllCredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/AllowAllCredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
 
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
 
 /**
  * A credentials matcher that always returns <tt>true</tt> when matching credentials no matter what arguments
  * are passed in.  This can be used for testing or when credentials are implicitly trusted for a particular
- * {@link org.ki.realm.Realm Realm}.
+ * {@link org.apache.ki.realm.Realm Realm}.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/CredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/CredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/CredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/CredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/CredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/CredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/CredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,19 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
 
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
 
 /**
  * Interface implemented by classes that can determine if an AuthenticationToken's provided
  * credentials matches a corresponding account's credentials stored in the system.
  *
  * <p>Simple direct comparisons are handled well by the
- * {@link org.ki.authc.credential.SimpleCredentialsMatcher SimpleCredentialsMatcher}.  If you
+ * {@link SimpleCredentialsMatcher SimpleCredentialsMatcher}.  If you
  * hash user's credentials before storing them in a realm (a common practice), look at the
- * {@link org.ki.authc.credential.HashedCredentialsMatcher HashedCredentialsMatcher} implementations,
+ * {@link HashedCredentialsMatcher HashedCredentialsMatcher} implementations,
  * as they support this scenario.
  *
  * @author Jeremy Haile

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/CredentialsMatcher.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/CredentialsMatcher.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/HashedCredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/HashedCredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/HashedCredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/HashedCredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/HashedCredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Md5CredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md5CredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import org.apache.ki.crypto.hash.AbstractHash;
+import org.apache.ki.crypto.hash.Hash;
+import org.apache.ki.crypto.hash.Md5Hash;
 
-import org.ki.crypto.hash.AbstractHash;
-import org.ki.crypto.hash.Hash;
-import org.ki.crypto.hash.Md5Hash;
 
 /**
  * <tt>HashedCredentialsMatcher</tt> implementation that expects the stored <tt>AuthenticationInfo</tt> credentials to be

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha1CredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha1CredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha1CredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha1CredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha1CredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha1CredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha1CredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import org.apache.ki.crypto.hash.AbstractHash;
+import org.apache.ki.crypto.hash.Hash;
+import org.apache.ki.crypto.hash.Sha1Hash;
 
-import org.ki.crypto.hash.AbstractHash;
-import org.ki.crypto.hash.Hash;
-import org.ki.crypto.hash.Sha1Hash;
 
 /**
  * <tt>HashedCredentialsMatcher</tt> implementation that expects the stored <tt>AuthenticationInfo</tt> credentials to be

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha256CredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha256CredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha256CredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha256CredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha256CredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AllSuccessfulStrategy.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AllSuccessfulStrategy.java Wed Mar 11 05:40:38 2009
@@ -16,15 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.pam;
+package org.apache.ki.authc.pam;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.ki.authc.AuthenticationException;
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
-import org.ki.authc.UnknownAccountException;
-import org.ki.realm.Realm;
+
+import org.apache.ki.authc.AuthenticationException;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
+import org.apache.ki.authc.UnknownAccountException;
+import org.apache.ki.realm.Realm;
+
 
 /**
  * <tt>AuthenticationStrategy</tt> implementation that requires <em>all</em> configured realms to
@@ -44,9 +46,9 @@
 
     /**
      * Because all realms in this strategy must complete successfully, this implementation ensures that the given
-     * <code>Realm</code> {@link Realm#supports(org.ki.authc.AuthenticationToken) supports} the given
+     * <code>Realm</code> {@link org.apache.ki.realm.Realm#supports(org.apache.ki.authc.AuthenticationToken) supports} the given
      * <code>token</code> argument.  If it does not, this method throws an
-     * {@link org.ki.authc.pam.UnsupportedTokenException UnsupportedTokenException} to end the authentication
+     * {@link UnsupportedTokenException UnsupportedTokenException} to end the authentication
      * process immediately. If the realm does support the token, the <code>info</code> argument is returned immediately.
      */
     public AuthenticationInfo beforeAttempt(Realm realm, AuthenticationToken token, AuthenticationInfo info) throws AuthenticationException {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AtLeastOneSuccessfulStrategy.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AtLeastOneSuccessfulStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AtLeastOneSuccessfulStrategy.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AtLeastOneSuccessfulStrategy.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AtLeastOneSuccessfulStrategy.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AtLeastOneSuccessfulStrategy.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AtLeastOneSuccessfulStrategy.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.pam;
+package org.apache.ki.authc.pam;
 
-import org.ki.authc.AuthenticationException;
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
+import org.apache.ki.authc.AuthenticationException;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
 
 /**
  * <tt>AuthenticationStrategy</tt> implementation that requires <em>at least one</em> configured realm to
@@ -43,7 +43,7 @@
 
     /**
      * Ensures that the <code>aggregate</code> method argument is not <code>null</code> and
-     * <code>aggregate.{@link org.ki.authc.AuthenticationInfo#getPrincipals() getPrincipals()}</code>
+     * <code>aggregate.{@link org.apache.ki.authc.AuthenticationInfo#getPrincipals() getPrincipals()}</code>
      * is not <code>null</code>, and if either is <code>null</code>, throws an AuthenticationException to indicate
      * that none of the realms authenticated successfully.
      */

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AuthenticationStrategy.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AuthenticationStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AuthenticationStrategy.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AuthenticationStrategy.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AuthenticationStrategy.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/pam/FirstSuccessfulStrategy.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/FirstSuccessfulStrategy.java Wed Mar 11 05:40:38 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.pam;
-
-import org.ki.authc.AuthenticationException;
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
-import org.ki.realm.Realm;
+package org.apache.ki.authc.pam;
 
 import java.util.Collection;
 
+import org.apache.ki.authc.AuthenticationException;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
+import org.apache.ki.realm.Realm;
+
 /**
  * {@link AuthenticationStrategy} implementation that only accepts the account data from
  * the first successfully consulted Realm and ignores all subsequent realms.  This is slightly

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/ModularRealmAuthenticator.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/pam/ModularRealmAuthenticator.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/ModularRealmAuthenticator.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/ModularRealmAuthenticator.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/pam/ModularRealmAuthenticator.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/pam/ModularRealmAuthenticator.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/ModularRealmAuthenticator.java Wed Mar 11 05:40:38 2009
@@ -16,18 +16,24 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.pam;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-import org.ki.authc.*;
-import org.ki.realm.Realm;
-import org.ki.subject.PrincipalCollection;
+package org.apache.ki.authc.pam;
 
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
+import org.apache.ki.authc.AbstractAuthenticator;
+import org.apache.ki.authc.AuthenticationException;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
+import org.apache.ki.authc.LogoutAware;
+import org.apache.ki.authc.UnknownAccountException;
+import org.apache.ki.realm.Realm;
+import org.apache.ki.subject.PrincipalCollection;
+
 /**
  * A <tt>ModularRealmAuthenticator</tt> delgates account lookups to a pluggable (modular) collection of
  * {@link Realm}s.  This enables PAM (Pluggable Authentication Module) behavior in JSecurity.
@@ -39,7 +45,7 @@
  *
  * <p>If only one realm is configured (this is often the case for most applications), authentication success is naturally
  * only dependent upon invoking this one Realm's
- * {@link Realm#getAuthenticationInfo(org.ki.authc.AuthenticationToken)} method.
+ * {@link Realm#getAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)} method.
  *
  * <p>But if two or more realms are configured, PAM behavior is implemented by iterating over the collection of realms
  * and interacting with each over the course of the authentication attempt.  As this is more complicated, this
@@ -280,11 +286,11 @@
 
     /**
      * <p>Attempts to authenticate the given token by iterating over the internal collection of
-     * {@link Realm}s.  For each realm, first the {@link Realm#supports(org.ki.authc.AuthenticationToken)}
+     * {@link Realm}s.  For each realm, first the {@link Realm#supports(org.apache.ki.authc.AuthenticationToken)}
      * method will be called to determine if the realm supports the <tt>authenticationToken</tt> method argument.
      *
      * If a realm does support
-     * the token, its {@link Realm#getAuthenticationInfo(org.ki.authc.AuthenticationToken)}
+     * the token, its {@link Realm#getAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)}
      * method will be called.  If the realm returns a non-null account, the token will be
      * considered authenticated for that realm and the account data recorded.  If the realm returns <tt>null</tt>,
      * the next realm will be consulted.  If no realms support the token or all supporting realms return null,
--- incubator/jsecurity/trunk/core/src/org/ki/aop/AnnotationHandler.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationHandler.java Wed Mar 11 05:40:38 2009
@@ -16,13 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.aop;
-
-import org.ki.SecurityUtils;
-import org.ki.subject.Subject;
+package org.apache.ki.aop;
 
 import java.lang.annotation.Annotation;
 
+import org.apache.ki.SecurityUtils;
+import org.apache.ki.subject.Subject;
+
+
 /**
  * Base support class for implementations that reads and processes JSR-175 annotations.
  *
@@ -47,11 +48,11 @@
     }
 
     /**
      * Returns the {@link org.ki.subject.Subject Subject} associated with the currently-executing code.
      * <p/>
      * This default implementation merely calls <code>{@link org.ki.SecurityUtils#getSubject SecurityUtils.getSubject()}</code>.
      *
      * @return the {@link org.ki.subject.Subject Subject} associated with the currently-executing code.
      */
     protected Subject getSubject() {
         return SecurityUtils.getSubject();
@@ -47,11 +48,11 @@
 
     /**
-     * Returns the {@link org.ki.subject.Subject Subject} associated with the currently-executing code.
+     * Returns the {@link org.apache.ki.subject.Subject Subject} associated with the currently-executing code.
      * <p/>
@@ -47,11 +48,11 @@
      * <p/>
-     * This default implementation merely calls <code>{@link org.ki.SecurityUtils#getSubject SecurityUtils.getSubject()}</code>.
+     * This default implementation merely calls <code>{@link org.apache.ki.SecurityUtils#getSubject SecurityUtils.getSubject()}</code>.
      *
@@ -47,11 +48,11 @@
      *
-     * @return the {@link org.ki.subject.Subject Subject} associated with the currently-executing code.
+     * @return the {@link org.apache.ki.subject.Subject Subject} associated with the currently-executing code.
      */
     protected Subject getSubject() {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationMethodInterceptor.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/aop/AnnotationMethodInterceptor.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationMethodInterceptor.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/aop/AnnotationMethodInterceptor.java&p1=incubator/jsecurity/trunk/core/src/org/ki/aop/AnnotationMethodInterceptor.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInterceptorSupport.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInterceptorSupport.java Wed Mar 11 05:40:38 2009
@@ -35,10 +35,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.aop;
+package org.apache.ki.aop;
+
+import org.apache.ki.SecurityUtils;
+import org.apache.ki.subject.Subject;
 
-import org.ki.SecurityUtils;
-import org.ki.subject.Subject;
 
 /**
  * This class is an abstraction of AOP method interceptor behavior specific to JSecurity that
@@ -48,7 +49,8 @@
  * @author Les Hazlewood
  * @since 0.2
  */
-public abstract class MethodInterceptorSupport implements MethodInterceptor {
+public abstract class MethodInterceptorSupport implements MethodInterceptor
+{
 
     /**
      * Default no-argument constructor for subclasses.
@@ -59,9 +61,9 @@
     /**
      * Returns the {@link Subject Subject} associated with the currently-executing code.
      * <p/>
      * This default implementation merely calls <code>{@link SecurityUtils#getSubject SecurityUtils.getSubject()}</code>.
      *
      * @return the {@link Subject Subject} associated with the currently-executing code.
      */
     protected Subject getSubject() {
         return SecurityUtils.getSubject();
@@ -59,9 +61,9 @@
      * Returns the {@link Subject Subject} associated with the currently-executing code.
      * <p/>
-     * This default implementation merely calls <code>{@link SecurityUtils#getSubject SecurityUtils.getSubject()}</code>.
+     * This default implementation merely calls <code>{@link org.apache.ki.SecurityUtils#getSubject SecurityUtils.getSubject()}</code>.
      *
@@ -59,9 +61,9 @@
      *
-     * @return the {@link Subject Subject} associated with the currently-executing code.
+     * @return the {@link org.apache.ki.subject.Subject Subject} associated with the currently-executing code.
      */
     protected Subject getSubject() {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInvocation.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInvocation.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInvocation.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/aop/MethodInvocation.java&p1=incubator/jsecurity/trunk/core/src/org/ki/aop/MethodInvocation.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/AbstractAuthenticator.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AbstractAuthenticator.java Wed Mar 11 05:40:38 2009
@@ -16,14 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
+
+import java.util.ArrayList;
+import java.util.Collection;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.ki.subject.PrincipalCollection;
 
-import java.util.ArrayList;
-import java.util.Collection;
+import org.apache.ki.subject.PrincipalCollection;
+
 
 /**
  * Superclass for almost all {@link Authenticator} implementations that performs the common work around authentication
@@ -31,7 +33,7 @@
  *
  * <p>This class delegates the actual authentication attempt to subclasses but supports notification for
  * successful and failed logins as well as logouts. Notification is sent to one or more registered
- * {@link org.ki.authc.AuthenticationListener AuthenticationListener}s to allow for custom processing logic
+ * {@link AuthenticationListener AuthenticationListener}s to allow for custom processing logic
  * when these conditions occur.
  *
  * <p>In most cases, the only thing a subclass needs to do (via its {@link #doAuthenticate} implementation)
@@ -89,10 +91,10 @@
     |               M E T H O D S               |
     ============================================*/
     /**
-     * Notifies any registered {@link org.ki.authc.AuthenticationListener AuthenticationListener}s that
+     * Notifies any registered {@link AuthenticationListener AuthenticationListener}s that
      * authentication was successful for the specified <code>token</code> which resulted in the specified
      * <code>info</code>.  This implementation merely iterates over the internal <code>listeners</code> collection and
-     * calls {@link org.ki.authc.AuthenticationListener#onSuccess(AuthenticationToken, AuthenticationInfo) onSuccess}
+     * calls {@link AuthenticationListener#onSuccess(AuthenticationToken, AuthenticationInfo) onSuccess}
      * for each.
      * @param token the submitted <code>AuthenticationToken</code> that resulted in a successful authentication.
      * @param info the returned <code>AuthenticationInfo</code> resulting from the successful authentication.
@@ -104,11 +106,11 @@
     }
 
     /**
-     * Notifies any registered {@link org.ki.authc.AuthenticationListener AuthenticationListener}s that
+     * Notifies any registered {@link AuthenticationListener AuthenticationListener}s that
      * authentication failed for the
      * specified <code>token</code> which resulted in the specified <code>ae</code> exception.  This implementation merely
      * iterates over the internal <code>listeners</code> collection and calls
-     * {@link org.ki.authc.AuthenticationListener#onFailure(AuthenticationToken, AuthenticationException) onFailure}
+     * {@link AuthenticationListener#onFailure(AuthenticationToken, AuthenticationException) onFailure}
      * for each.
      * @param token the submitted <code>AuthenticationToken</code> that resulted in a failed authentication.
      * @param ae the resulting <code>AuthenticationException<code> that caused the authentication to fail.
@@ -120,10 +122,10 @@
     }
 
     /**
-     * Notifies any registered {@link org.ki.authc.AuthenticationListener AuthenticationListener}s that a
+     * Notifies any registered {@link AuthenticationListener AuthenticationListener}s that a
      * <code>Subject</code> has logged-out.  This implementation merely
      * iterates over the internal <code>listeners</code> collection and calls
-     * {@link org.ki.authc.AuthenticationListener#onLogout(org.ki.subject.PrincipalCollection) onLogout}
+     * {@link AuthenticationListener#onLogout(org.apache.ki.subject.PrincipalCollection) onLogout}
      * for each.
      * @param principals the identifying principals of the <code>Subject</code>/account logging out.
      */
@@ -135,7 +137,7 @@
 
     /**
      * This implementation merely calls
      * {@link #notifyLogout(org.ki.subject.PrincipalCollection) notifyLogout} to allow any registered listeners
      * to react to the logout.
      * @param principals the identifying principals of the <code>Subject</code>/account logging out.
      */

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AbstractAuthenticator.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AbstractAuthenticator.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision
@@ -135,7 +137,7 @@
     /**
      * This implementation merely calls
-     * {@link #notifyLogout(org.ki.subject.PrincipalCollection) notifyLogout} to allow any registered listeners
+     * {@link #notifyLogout(org.apache.ki.subject.PrincipalCollection) notifyLogout} to allow any registered listeners
      * to react to the logout.
      * @param principals the identifying principals of the <code>Subject</code>/account logging out.

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Account.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/Account.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Account.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Account.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/Account.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/Account.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Account.java Wed Mar 11 05:40:38 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
-import org.ki.authz.AuthorizationInfo;
+import org.apache.ki.authz.AuthorizationInfo;
 
 /**
  * An <tt>Account</tt> is a convenience interface that extends both {@link AuthenticationInfo} and
  * {@link AuthorizationInfo} and represents authentication and authorization for a <em>single account</em> in a
  * <em>single Realm</em>.
  * <p/>
  * This interface can be useful when an Realm implementation finds it more convenient to use a single object to

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Account.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Account.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision
@@ -16,13 +16,13 @@
 /**
  * An <tt>Account</tt> is a convenience interface that extends both {@link AuthenticationInfo} and
- * {@link AuthorizationInfo} and represents authentication and authorization for a <em>single account</em> in a
+ * {@link org.apache.ki.authz.AuthorizationInfo} and represents authentication and authorization for a <em>single account</em> in a
  * <em>single Realm</em>.
  * <p/>

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AccountException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/AccountException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AccountException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AccountException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/AccountException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationInfo.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationInfo.java Wed Mar 11 05:40:38 2009
@@ -17,12 +17,12 @@
  * under the License.
  */
 
-package org.ki.authc;
-
-import org.ki.subject.PrincipalCollection;
+package org.apache.ki.authc;
 
 import java.io.Serializable;
 
+import org.apache.ki.subject.PrincipalCollection;
+
 /**
  * <code>AuthenticationInfo</code> represents a Subject's (aka user's) stored account information relevant to the
  * authentication/log-in process only.
@@ -35,10 +35,10 @@
  * <p/>
  * Because the act of authentication (log-in) is orthoganal to authorization (access control), this interface is
  * intended to represent only the account data needed by JSecurity during an authentication attempt.  JSecurity also
  * has a parallel {@link org.ki.authz.AuthorizationInfo AuthorizationInfo} interface for use during the
  * authorization process that references access control data such as roles and permissions.
  * <p/>
  * But because many if not most {@link org.ki.realm.Realm Realm}s store both sets of data for a Subject, it might be
  * convenient for a <code>Realm</code> implementation to utilize an implementation of the {@link Account Account}
  * interface instead, which is a convenience interface that combines both <code>AuthenticationInfo</code> and
  * <code>AuthorizationInfo</code>.  Whether you choose to implement these two interfaces separately or implement the one
@@ -53,7 +53,7 @@
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see org.ki.authz.AuthorizationInfo AuthorizationInfo
+ * @see org.apache.ki.authz.AuthorizationInfo AuthorizationInfo
  * @see Account
  * @since 0.9
  */
@@ -35,10 +35,10 @@
  * Because the act of authentication (log-in) is orthoganal to authorization (access control), this interface is
  * intended to represent only the account data needed by JSecurity during an authentication attempt.  JSecurity also
- * has a parallel {@link org.ki.authz.AuthorizationInfo AuthorizationInfo} interface for use during the
+ * has a parallel {@link org.apache.ki.authz.AuthorizationInfo AuthorizationInfo} interface for use during the
  * authorization process that references access control data such as roles and permissions.
  * <p/>
@@ -35,10 +35,10 @@
  * authorization process that references access control data such as roles and permissions.
  * <p/>
- * But because many if not most {@link org.ki.realm.Realm Realm}s store both sets of data for a Subject, it might be
+ * But because many if not most {@link org.apache.ki.realm.Realm Realm}s store both sets of data for a Subject, it might be
  * convenient for a <code>Realm</code> implementation to utilize an implementation of the {@link Account Account}
  * interface instead, which is a convenience interface that combines both <code>AuthenticationInfo</code> and

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListener.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationListener.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListener.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListener.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationListener.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationListener.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListener.java Wed Mar 11 05:40:38 2009
@@ -16,13 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
+
+import org.apache.ki.subject.PrincipalCollection;
 
-import org.ki.subject.PrincipalCollection;
 
 /**
  * An <code>AuthenticationListener</code> listens for notifications while
  * {@link org.ki.subject.Subject Subject}s authenticate with the system.
  *
  * @author Les Hazlewood
  * @since 0.9
@@ -16,13 +16,14 @@
 /**
  * An <code>AuthenticationListener</code> listens for notifications while
- * {@link org.ki.subject.Subject Subject}s authenticate with the system.
+ * {@link org.apache.ki.subject.Subject Subject}s authenticate with the system.
  *
  * @author Les Hazlewood

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListenerRegistrar.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationListenerRegistrar.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListenerRegistrar.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/AuthenticationListenerRegistrar.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/AuthenticationListenerRegistrar.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/Authenticator.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Authenticator.java Wed Mar 11 05:40:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 /**
  * An Authenticator is responsible for authenticating accounts in an application.  It
@@ -25,7 +25,7 @@
  * Although not a requirement, there is usually a single 'master' Authenticator configured for
  * an application.  Enabling Pluggable Authentication Module (PAM) behavior
  * (Two Phase Commit, etc.) is usually achieved by the single {@code Authenticator} coordinating
  * and interacting with an application-configured set of {@link org.ki.realm.Realm Realm}s.
  * <p/>
  * Note that most JSecurity users will not interact with an {@code Authenticator} instance directly.
  * JSecurity's default architecture is based on an overall {@code SecurityManager} which typically
@@ -33,9 +33,9 @@
  *
  * @author Les Hazlewood
  * @author Jeremy Haile
- * @see org.ki.mgt.SecurityManager
+ * @see org.apache.ki.mgt.SecurityManager
  * @see AbstractAuthenticator AbstractAuthenticator
- * @see org.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator
+ * @see org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator
  * @since 0.1
  */
 public interface Authenticator {

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Authenticator.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/Authenticator.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision
@@ -25,7 +25,7 @@
  * an application.  Enabling Pluggable Authentication Module (PAM) behavior
  * (Two Phase Commit, etc.) is usually achieved by the single {@code Authenticator} coordinating
- * and interacting with an application-configured set of {@link org.ki.realm.Realm Realm}s.
+ * and interacting with an application-configured set of {@link org.apache.ki.realm.Realm Realm}s.
  * <p/>
  * Note that most JSecurity users will not interact with an {@code Authenticator} instance directly.

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ConcurrentAccessException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/ConcurrentAccessException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ConcurrentAccessException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/ConcurrentAccessException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/ConcurrentAccessException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/SimpleAccount.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAccount.java Wed Mar 11 05:40:38 2009
@@ -16,19 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
-
-import org.ki.authz.Permission;
-import org.ki.authz.SimpleAuthorizationInfo;
-import org.ki.subject.PrincipalCollection;
-import org.ki.subject.SimplePrincipalCollection;
+package org.apache.ki.authc;
 
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.Set;
 
+import org.apache.ki.authz.Permission;
+import org.apache.ki.authz.SimpleAuthorizationInfo;
+import org.apache.ki.subject.PrincipalCollection;
+import org.apache.ki.subject.SimplePrincipalCollection;
+
+
 /**
  * Simple implementation of the {@link org.ki.authc.Account} interface that
  * contains principal and credential and authorization information (roles and permissions) as instance variables and
  * exposes them via getters and setters using standard JavaBean notation.
  *
@@ -53,13 +54,13 @@
 
     /**
      * Indicates this account is locked.  This isn't honored by all <tt>Realms</tt> but is honored by
-     * {@link org.ki.realm.SimpleAccountRealm}.
+     * {@link org.apache.ki.realm.SimpleAccountRealm}.
      */
     private boolean locked;
 
     /**
      * Indicates credentials on this account are expired.  This isn't honored by all <tt>Realms</tt> but is honored by
-     * {@link org.ki.realm.SimpleAccountRealm}.
+     * {@link org.apache.ki.realm.SimpleAccountRealm}.
      */
     private boolean credentialsExpired;
 
@@ -215,7 +216,7 @@
      * {@link #getPrincipals() principals}, such as a password or private key.
      *
      * @param credentials the credentials associated with this Account that verify one or more of the Account principals.
-     * @see Account#getCredentials()
+     * @see org.apache.ki.authc.Account#getCredentials()
      */
     public void setCredentials(Object credentials) {
         this.authcInfo.setCredentials(credentials);
@@ -272,7 +273,7 @@
      * Sets the String-based permissions assigned to this Account.  Simply delegates to
      * <code>this.authzInfo.setStringPermissions(permissions)</code>.
      * @param permissions all String-based permissions assigned to this Account.
-     * @see Account#getStringPermissions()
+     * @see org.apache.ki.authc.Account#getStringPermissions()
      */
     public void setStringPermissions(Set<String> permissions) {
         this.authzInfo.setStringPermissions(permissions);

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAccount.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAccount.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision
@@ -16,19 +16,20 @@
 /**
- * Simple implementation of the {@link org.ki.authc.Account} interface that
+ * Simple implementation of the {@link org.apache.ki.authc.Account} interface that
  * contains principal and credential and authorization information (roles and permissions) as instance variables and
  * exposes them via getters and setters using standard JavaBean notation.

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAuthenticationInfo.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/SimpleAuthenticationInfo.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAuthenticationInfo.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAuthenticationInfo.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/SimpleAuthenticationInfo.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/SimpleAuthenticationInfo.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/SimpleAuthenticationInfo.java Wed Mar 11 05:40:38 2009
@@ -16,21 +16,22 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
-
-import org.ki.subject.MutablePrincipalCollection;
-import org.ki.subject.PrincipalCollection;
-import org.ki.subject.SimplePrincipalCollection;
+package org.apache.ki.authc;
 
 import java.util.Collection;
 import java.util.HashSet;
 import java.util.Set;
 
+import org.apache.ki.subject.MutablePrincipalCollection;
+import org.apache.ki.subject.PrincipalCollection;
+import org.apache.ki.subject.SimplePrincipalCollection;
+
+
 /**
  * Simple implementation of the {@link MergableAuthenticationInfo} interface that holds the principals and
  * credentials.
  *
- * @see org.ki.realm.AuthenticatingRealm
+ * @see org.apache.ki.realm.AuthenticatingRealm
  * @since 0.9
  * @author Jeremy Haile
  * @author Les Hazlewood
@@ -16,21 +16,22 @@
 /**
- * Simple implementation of the {@link MergableAuthenticationInfo} interface that holds the principals and
+ * Simple implementation of the {@link org.apache.ki.authc.MergableAuthenticationInfo} interface that holds the principals and
  * credentials.
  *

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UnknownAccountException.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/UnknownAccountException.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UnknownAccountException.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UnknownAccountException.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/UnknownAccountException.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/UsernamePasswordToken.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UsernamePasswordToken.java Wed Mar 11 05:40:38 2009
@@ -16,15 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc;
+package org.apache.ki.authc;
 
 import java.net.InetAddress;
 
+
 /**
  * <p>A simple username/password authentication token to support the most widely-used authentication mechanism.  This
  * class also implements the {@link RememberMeAuthenticationToken RememberMeAuthenticationToken} interface to support
  * &quot;Remember Me&quot; services across user sessions as well as the
  * {@link InetAuthenticationToken InetAuthenticationToken} interface to retain the IP address location from where the
  * authentication attempt is occuring.</p>
  *
  * <p>&quot;Remember Me&quot; authentications are disabled by default, but if the application developer wishes to allow
@@ -254,7 +255,7 @@
      * Simply returns {@link #getUsername() getUsername()}.
      *
      * @return the {@link #getUsername() username}.
-     * @see org.ki.authc.AuthenticationToken#getPrincipal()
+     * @see org.apache.ki.authc.AuthenticationToken#getPrincipal()
      */
     public Object getPrincipal() {
         return getUsername();
@@ -264,7 +265,7 @@
      * Returns the {@link #getPassword() password} char array.
      *
      * @return the {@link #getPassword() password} char array.
-     * @see org.ki.authc.AuthenticationToken#getCredentials()
+     * @see org.apache.ki.authc.AuthenticationToken#getCredentials()
      */
     public Object getCredentials() {
         return getPassword();

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UsernamePasswordToken.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/UsernamePasswordToken.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision
@@ -16,15 +16,16 @@
  * class also implements the {@link RememberMeAuthenticationToken RememberMeAuthenticationToken} interface to support
  * &quot;Remember Me&quot; services across user sessions as well as the
- * {@link InetAuthenticationToken InetAuthenticationToken} interface to retain the IP address location from where the
+ * {@link org.apache.ki.authc.InetAuthenticationToken InetAuthenticationToken} interface to retain the IP address location from where the
  * authentication attempt is occuring.</p>
  *

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/AllowAllCredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/AllowAllCredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/AllowAllCredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/AllowAllCredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/AllowAllCredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/HashedCredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/HashedCredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
 
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
-import org.ki.codec.Base64;
-import org.ki.codec.Hex;
-import org.ki.crypto.hash.AbstractHash;
-import org.ki.crypto.hash.Hash;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
+import org.apache.ki.codec.Base64;
+import org.apache.ki.codec.Hex;
+import org.apache.ki.crypto.hash.AbstractHash;
+import org.apache.ki.crypto.hash.Hash;
 
 /**
  * A <tt>HashedCredentialMatcher</tt> provides support for hashing of supplied <tt>AuthenticationToken</tt> credentials
@@ -49,7 +49,7 @@
  * &quot;Why add salt?&quot; and 6 "Hardening against the attacker's attack").
  *
  * <p>We should also note here that all of JSecurity's Hash implementations (for example,
- * {@link org.ki.crypto.hash.Md5Hash Md5Hash}, {@link org.ki.crypto.hash.Sha1Hash Sha1Hash}, etc)
+ * {@link org.apache.ki.crypto.hash.Md5Hash Md5Hash}, {@link org.apache.ki.crypto.hash.Sha1Hash Sha1Hash}, etc)
  * support salting and multiple hash iterations via overloaded constructors.</p>
  *
  * <h4>Salting</h4>
@@ -57,7 +57,7 @@
  * <p>Salting of the authentication token's credentials hash is disabled by default, but you may enable it by setting
  * {@link #setHashSalted hashSalted} to
  * <tt>true</tt>.  If you do enable it, the value used to salt the hash will be
- * obtained from {@link #getSalt(AuthenticationToken) getSalt(authenticationToken)}.
+ * obtained from {@link #getSalt(org.apache.ki.authc.AuthenticationToken) getSalt(authenticationToken)}.
  *
  * <p>The default <tt>getSalt</tt> implementation merely returns
  * <code>token.getPrincipal()</code>, effectively using the user's identity as the salt, a most common
@@ -76,9 +76,9 @@
  * supporting <code>CredentialsMatcher</code> implementations.</p>
  *
  * @author Les Hazlewood
  * @see org.ki.crypto.hash.Md5Hash
  * @see org.ki.crypto.hash.Sha1Hash
  * @see org.ki.crypto.hash.Sha256Hash
  * @since 0.9
  */
 public abstract class HashedCredentialsMatcher extends SimpleCredentialsMatcher {
@@ -137,7 +137,7 @@
     /**
      * Sets whether or not to salt a submitted <tt>AuthenticationToken</tt>'s credentials when hashing.
      *
      * <p>If enabled, the salt used will be obtained via the {@link #getSalt(AuthenticationToken) getSalt} method.
      *
      * <p>The default value is <tt>false</tt>.
      *
@@ -263,7 +263,7 @@
 
     /**
      * Returns a new, <em>uninitialized</em> instance, without its byte array set.  Used as a utility method in the
-     * {@link SimpleCredentialsMatcher#getCredentials(org.ki.authc.AuthenticationInfo) getCredentials(AuthenticationInfo)} implementation.
+     * {@link SimpleCredentialsMatcher#getCredentials(org.apache.ki.authc.AuthenticationInfo) getCredentials(AuthenticationInfo)} implementation.
      *
      * @return a new, <em>uninitialized</em> instance, without its byte array set.
      */
@@ -76,9 +76,9 @@
  *
  * @author Les Hazlewood
- * @see org.ki.crypto.hash.Md5Hash
- * @see org.ki.crypto.hash.Sha1Hash
- * @see org.ki.crypto.hash.Sha256Hash
+ * @see org.apache.ki.crypto.hash.Md5Hash
+ * @see org.apache.ki.crypto.hash.Sha1Hash
+ * @see org.apache.ki.crypto.hash.Sha256Hash
  * @since 0.9
  */
@@ -137,7 +137,7 @@
      * Sets whether or not to salt a submitted <tt>AuthenticationToken</tt>'s credentials when hashing.
      *
-     * <p>If enabled, the salt used will be obtained via the {@link #getSalt(AuthenticationToken) getSalt} method.
+     * <p>If enabled, the salt used will be obtained via the {@link #getSalt(org.apache.ki.authc.AuthenticationToken) getSalt} method.
      *
      * <p>The default value is <tt>false</tt>.

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md2CredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Md2CredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md2CredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md2CredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Md2CredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Md2CredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md2CredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import org.apache.ki.crypto.hash.AbstractHash;
+import org.apache.ki.crypto.hash.Hash;
+import org.apache.ki.crypto.hash.Md2Hash;
 
-import org.ki.crypto.hash.AbstractHash;
-import org.ki.crypto.hash.Hash;
-import org.ki.crypto.hash.Md2Hash;
 
 /**
  * <tt>HashedCredentialsMatcher</tt> implementation that expects the stored <tt>AuthenticationInfo</tt> credentials to be
@@ -40,7 +41,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Md2Hash Md2Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link Md2Hash Md2Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Md2Hash();
@@ -48,7 +49,7 @@
 
     /**
      * This implementation merely returns
-     * <code>new {@link Md2Hash#Md2Hash(Object, Object, int) Md2Hash(credentials,salt,hashIterations)}</code>.
+     * <code>new {@link org.apache.ki.crypto.hash.Md2Hash#Md2Hash(Object, Object, int) Md2Hash(credentials,salt,hashIterations)}</code>.
      */
     protected Hash hashProvidedCredentials(Object credentials, Object salt, int hashIterations) {
         return new Md2Hash(credentials, salt, hashIterations);
@@ -40,7 +41,7 @@
      * Creates a new <em>uninitialized</em> {@link Md2Hash Md2Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link Md2Hash Md2Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Md2Hash Md2Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md5CredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Md5CredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md5CredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Md5CredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Md5CredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha256CredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha256CredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import org.apache.ki.crypto.hash.AbstractHash;
+import org.apache.ki.crypto.hash.Hash;
+import org.apache.ki.crypto.hash.Sha256Hash;
 
-import org.ki.crypto.hash.AbstractHash;
-import org.ki.crypto.hash.Hash;
-import org.ki.crypto.hash.Sha256Hash;
 
 /**
  * <tt>HashedCredentialsMatcher</tt> implementation that expects the stored <tt>AuthenticationInfo</tt> credentials to be
@@ -34,7 +35,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Sha256Hash Sha256Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link Sha256Hash Sha256Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Sha256Hash();
@@ -34,7 +35,7 @@
      * Creates a new <em>uninitialized</em> {@link Sha256Hash Sha256Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link Sha256Hash Sha256Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha256Hash Sha256Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha384CredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha384CredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha384CredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha384CredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha384CredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha384CredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha384CredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import org.apache.ki.crypto.hash.AbstractHash;
+import org.apache.ki.crypto.hash.Hash;
+import org.apache.ki.crypto.hash.Sha384Hash;
 
-import org.ki.crypto.hash.AbstractHash;
-import org.ki.crypto.hash.Hash;
-import org.ki.crypto.hash.Sha384Hash;
 
 /**
  * <tt>HashedCredentialsMatcher</tt> implementation that expects the stored <tt>AuthenticationInfo</tt> credentials to be
@@ -34,7 +35,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Sha384Hash Sha384Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link Sha384Hash Sha384Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Sha384Hash();
@@ -34,7 +35,7 @@
      * Creates a new <em>uninitialized</em> {@link Sha384Hash Sha384Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link Sha384Hash Sha384Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha384Hash Sha384Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha512CredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha512CredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha512CredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha512CredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha512CredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/Sha512CredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/Sha512CredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,11 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import org.apache.ki.crypto.hash.AbstractHash;
+import org.apache.ki.crypto.hash.Hash;
+import org.apache.ki.crypto.hash.Sha512Hash;
 
-import org.ki.crypto.hash.AbstractHash;
-import org.ki.crypto.hash.Hash;
-import org.ki.crypto.hash.Sha512Hash;
 
 /**
  * <tt>HashedCredentialsMatcher</tt> implementation that expects the stored <tt>AuthenticationInfo</tt> credentials to be
@@ -34,7 +35,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Sha512Hash Sha512Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link Sha512Hash Sha512Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Sha512Hash();
@@ -34,7 +35,7 @@
      * Creates a new <em>uninitialized</em> {@link Sha512Hash Sha512Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link Sha512Hash Sha512Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha512Hash Sha512Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/SimpleCredentialsMatcher.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/credential/SimpleCredentialsMatcher.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/SimpleCredentialsMatcher.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/SimpleCredentialsMatcher.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/credential/SimpleCredentialsMatcher.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/credential/SimpleCredentialsMatcher.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/credential/SimpleCredentialsMatcher.java Wed Mar 11 05:40:38 2009
@@ -16,15 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.credential;
+package org.apache.ki.authc.credential;
+
+import java.util.Arrays;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
-import org.ki.codec.CodecSupport;
 
-import java.util.Arrays;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
+import org.apache.ki.codec.CodecSupport;
+
 
 /**
  * Simple CredentialsMatcher implementation.  Supports direct (plain) comparison for credentials of type
@@ -32,11 +34,11 @@
  * <code>Object.equals</code> comparison.
  *
  * <p>Hashing comparisons (the most common technique used in secure applications) are not supported by this class, but
  * instead by {@link HashedCredentialsMatcher HashedCredentialsMatcher} implementations.
  *
  * @author Les Hazlewood
- * @see HashedCredentialsMatcher
- * @see Md5CredentialsMatcher
+ * @see org.apache.ki.authc.credential.HashedCredentialsMatcher
+ * @see org.apache.ki.authc.credential.Md5CredentialsMatcher
  * @see Sha1CredentialsMatcher
  * @since 0.9
  */
@@ -116,7 +118,7 @@
      * This implementation acquires the <tt>token</tt>'s credentials
      * (via {@link #getCredentials(AuthenticationToken) getCredentials(token)})
      * and then the <tt>account</tt>'s credentials
      * (via {@link #getCredentials(org.ki.authc.AuthenticationInfo) getCredentials(account)}) and then passes both of
      * them to the {@link #equals(Object,Object) equals(tokenCredentials, accountCredentials)} method for equality
      * comparison.
      *
@@ -32,11 +34,11 @@
  *
  * <p>Hashing comparisons (the most common technique used in secure applications) are not supported by this class, but
- * instead by {@link HashedCredentialsMatcher HashedCredentialsMatcher} implementations.
+ * instead by {@link org.apache.ki.authc.credential.HashedCredentialsMatcher HashedCredentialsMatcher} implementations.
  *
  * @author Les Hazlewood
@@ -116,7 +118,7 @@
      * (via {@link #getCredentials(AuthenticationToken) getCredentials(token)})
      * and then the <tt>account</tt>'s credentials
-     * (via {@link #getCredentials(org.ki.authc.AuthenticationInfo) getCredentials(account)}) and then passes both of
+     * (via {@link #getCredentials(org.apache.ki.authc.AuthenticationInfo) getCredentials(account)}) and then passes both of
      * them to the {@link #equals(Object,Object) equals(tokenCredentials, accountCredentials)} method for equality
      * comparison.

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AbstractAuthenticationStrategy.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AbstractAuthenticationStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AbstractAuthenticationStrategy.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AbstractAuthenticationStrategy.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AbstractAuthenticationStrategy.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AbstractAuthenticationStrategy.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AbstractAuthenticationStrategy.java Wed Mar 11 05:40:38 2009
@@ -16,13 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.pam;
-
-import org.ki.authc.*;
-import org.ki.realm.Realm;
+package org.apache.ki.authc.pam;
 
 import java.util.Collection;
 
+import org.apache.ki.authc.AuthenticationException;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
+import org.apache.ki.authc.MergableAuthenticationInfo;
+import org.apache.ki.authc.SimpleAuthenticationInfo;
+import org.apache.ki.realm.Realm;
+
+
 /**
  * Abstract base implementation for JSecurity's concrete <code>AuthenticationStrategy</code>
  * implementations.
@@ -34,7 +39,7 @@
 public abstract class AbstractAuthenticationStrategy implements AuthenticationStrategy {
 
     /**
      * Simply returns <code>new {@link SimpleAuthenticationInfo SimpleAuthenticationInfo}();</code>, which supports
      * aggregating account data across realms.
      */
     public AuthenticationInfo beforeAllAttempts(Collection<? extends Realm> realms, AuthenticationToken token) throws AuthenticationException {
@@ -72,11 +77,11 @@
      * aggregate for continued use throughout the login process.
      * <p/>
      * This implementation merely checks to see if the specified <code>aggregate</code> argument is an instance of
      * {@link org.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo}, and if so, calls
      * <code>aggregate.merge(info)</code>  If it is <em>not</em> an instance of
      * <code>MergableAuthenticationInfo</code>, an {@link IllegalArgumentException IllegalArgumentException} is thrown.
      * Can be overridden by subclasses for custom merging behavior if implementing the
      * {@link org.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo} is not desired for some reason.
      */
     protected AuthenticationInfo merge(AuthenticationInfo info, AuthenticationInfo aggregate) {
         if( aggregate instanceof MergableAuthenticationInfo ) {
@@ -34,7 +39,7 @@
 
     /**
-     * Simply returns <code>new {@link SimpleAuthenticationInfo SimpleAuthenticationInfo}();</code>, which supports
+     * Simply returns <code>new {@link org.apache.ki.authc.SimpleAuthenticationInfo SimpleAuthenticationInfo}();</code>, which supports
      * aggregating account data across realms.
      */
@@ -72,11 +77,11 @@
      * <p/>
      * This implementation merely checks to see if the specified <code>aggregate</code> argument is an instance of
-     * {@link org.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo}, and if so, calls
+     * {@link org.apache.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo}, and if so, calls
      * <code>aggregate.merge(info)</code>  If it is <em>not</em> an instance of
      * <code>MergableAuthenticationInfo</code>, an {@link IllegalArgumentException IllegalArgumentException} is thrown.
@@ -72,11 +77,11 @@
      * <code>MergableAuthenticationInfo</code>, an {@link IllegalArgumentException IllegalArgumentException} is thrown.
      * Can be overridden by subclasses for custom merging behavior if implementing the
-     * {@link org.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo} is not desired for some reason.
+     * {@link org.apache.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo} is not desired for some reason.
      */
     protected AuthenticationInfo merge(AuthenticationInfo info, AuthenticationInfo aggregate) {

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AllSuccessfulStrategy.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AllSuccessfulStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AllSuccessfulStrategy.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AllSuccessfulStrategy.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AllSuccessfulStrategy.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================
--- incubator/jsecurity/trunk/core/src/org/ki/authc/pam/AuthenticationStrategy.java (original)
+++ incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/AuthenticationStrategy.java Wed Mar 11 05:40:38 2009
@@ -16,15 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.ki.authc.pam;
-
-import org.ki.authc.AuthenticationException;
-import org.ki.authc.AuthenticationInfo;
-import org.ki.authc.AuthenticationToken;
-import org.ki.realm.Realm;
+package org.apache.ki.authc.pam;
 
 import java.util.Collection;
 
+import org.apache.ki.authc.AuthenticationException;
+import org.apache.ki.authc.AuthenticationInfo;
+import org.apache.ki.authc.AuthenticationToken;
+import org.apache.ki.realm.Realm;
+
+
 /**
  * A <tt>AuthenticationStrategy</tt> implementation assists the {@link ModularRealmAuthenticator} during the
  * log-in process in a pluggable realm (PAM) environment.
@@ -71,7 +72,7 @@
      * @param aggregate the aggregated AuthenticationInfo object being used across the multi-realm authentication attempt
      * @return the AuthenticationInfo object that will be presented to further realms in the authentication process - returning
      *         the <code>aggregate</code> method argument is the normal case if no special action needs to be taken.
      * @throws AuthenticationException an exception thrown by the Strategy implementation if it wishes the login
      *                                 process for the associated subject (user) to stop immediately.
      */
     AuthenticationInfo beforeAttempt(Realm realm, AuthenticationToken token, AuthenticationInfo aggregate) throws AuthenticationException;
@@ -71,7 +72,7 @@
      * @return the AuthenticationInfo object that will be presented to further realms in the authentication process - returning
      *         the <code>aggregate</code> method argument is the normal case if no special action needs to be taken.
-     * @throws AuthenticationException an exception thrown by the Strategy implementation if it wishes the login
+     * @throws org.apache.ki.authc.AuthenticationException an exception thrown by the Strategy implementation if it wishes the login
      *                                 process for the associated subject (user) to stop immediately.
      */

Copied: incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/FirstSuccessfulStrategy.java (from r752240, incubator/jsecurity/trunk/core/src/org/ki/authc/pam/FirstSuccessfulStrategy.java)
URL: http://svn.apache.org/viewvc/incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/FirstSuccessfulStrategy.java?p2=incubator/jsecurity/trunk/core/src/org/apache/ki/authc/pam/FirstSuccessfulStrategy.java&p1=incubator/jsecurity/trunk/core/src/org/ki/authc/pam/FirstSuccessfulStrategy.java&r1=752240&r2=752380&rev=752380&view=diff
==============================================================================